﻿package
{
   import flash.display.StageAlign;
   import flash.display.StageScaleMode;
   import flash.display.Sprite;
   import flash.text.TextField;
   import flash.events.Event;   
   import flash.system.Capabilities;
   import flash.sensors.Accelerometer;
   import flash.events.AccelerometerEvent;
   import flash.events.MouseEvent;
   import flash.desktop.NativeApplication;
   import flash.desktop.SystemIdleMode;
 
   public class TestApp extends Sprite
   {
      private var bcg:Sprite;
      private var ball:Sprite;
      private var info_txt:TextField;
      private var info:String;
      private var stageWidth, stageHeight, heightOffset, accX, accY:Number;
      private var acc:Accelerometer;
 
      public function TestApp() 
      {
         //stage has no scale, we will lay it out properly
         stage.scaleMode = StageScaleMode.NO_SCALE;
         stage.align = StageAlign.TOP_LEFT;
 
         //as soon as the stage is resized (or creted) 
         //we will create our graphics objects
         stage.addEventListener(Event.RESIZE, init);
 
         //prevent screen dimming
         //Persmissions xml file has to have android.permission.WAKE_LOCK 
         //android.permission.DISABLE_KEYGUARD enabled!
         NativeApplication.nativeApplication.systemIdleMode = 
                                               SystemIdleMode.KEEP_AWAKE;
      }
 
      private function init(e:Event):void
      {
         //we don't need to lister for resize event anymore 
         //as the stage orientation is fixed and will not change
         stage.removeEventListener(Event.RESIZE, init);
 
         //get the fullscreen size of the stage. 
         //It will cover the status bar of Android and iOS
		 //On iOS it returns width smaller than height on landscape mode(a bug?)
		 //so we need to find a larger value and make it width
         stageWidth = Math.max(stage.fullScreenWidth, stage.fullScreenHeight);
         stageHeight = Math.min(stage.fullScreenWidth, stage.fullScreenHeight);
         heightOffset = stageHeight * .2;
 
         //creating bcg image with full stage width and height 60% of stage height
         bcg = new Sprite();
         bcg.graphics.beginFill(0xcdd6df);
         bcg.graphics.drawRoundRect(0, heightOffset, 
                             stageWidth, stageHeight - 2 * heightOffset, 50, 50);
         bcg.graphics.endFill();
 
         //creating ball image
         ball = new Sprite();
         ball.graphics.beginFill(0xFF0000);
         ball.graphics.drawCircle(0, 0, heightOffset * .5);
         ball.graphics.endFill();
         ball.cacheAsBitmap = true;
         ball.x = stageWidth * .5;
         ball.y = stageHeight - 2 * heightOffset;
 
         //creating text field with some system info
         info = "Detected resolution: " + stageWidth + "x" + stageHeight;
         info += "\nDevice type: " + Capabilities.manufacturer;
         info_txt = new TextField();
         info_txt.width = 200;
         info_txt.text = info;
         info_txt.x = stageWidth * .5 - info_txt.width * .5;
         info_txt.y = stageHeight * .5 - info_txt.height * .5;
 
         //converting vectors to bitmap and adding everything on stage
         bcg.addChild(info_txt);
         bcg.cacheAsBitmap = true;
         addChild(bcg);
         addChild(ball);
 
         //if accelerometer is available then activate it to control the ball
         if (Accelerometer.isSupported)
         {
            acc = new Accelerometer();
            acc.addEventListener(AccelerometerEvent.UPDATE, accUpdate);
            addEventListener(Event.ENTER_FRAME, updateBall);
         }
 
         //if running on everything else than iOS activae exit by touching the ball
         if (Capabilities.manufacturer.indexOf("iOS") == -1)
         {
            ball.addEventListener(MouseEvent.MOUSE_DOWN, 
                      function(){NativeApplication.nativeApplication.exit();});
         }
      }
 
      //handler for accelerometer
      private function accUpdate(e:AccelerometerEvent):void
      {
         accX = e.accelerationX;
         accY = e.accelerationY;
      }
 
      //handler to move the ball
      private function updateBall(e:Event):void
      {
         ball.x -= accX * 30;
         ball.y += accY * 30;
 
         if (ball.x > stageWidth - ball.width * .5)
            ball.x = stageWidth - ball.width * .5;
 
         if (ball.x < ball.width * .5)
            ball.x = ball.width * .5;
 
         if (ball.y >  stageHeight - ball.height * .5)
            ball.y = stageHeight - ball.height * .5;
 
         if (ball.y < ball.height * .5)
            ball.y = ball.height * .5;
      }
   }
}